require 'logger'

require 'spotify'

module Support
  module_function

  @@logger = Logger.new('support.log', 2, 1_000_000)
  @@logger.formatter = proc do |severity, datetime, _progname, msg|
    "\n\n#{datetime} #{severity}:\n\t#{msg}"
  end
  @@logger.level = Logger::DEBUG

  DEFAULT_CONFIG = {
    api_version: Spotify::API_VERSION.to_i,
    application_key: File.binread('spotify_appkey.key'),
    cache_location: '.spotify/',
    settings_location: '.spotify/',
    user_agent: 'Partygoer',
    callbacks: Spotify::SessionCallbacks.new
  }

  def initialize_spotify!(username, password, config = DEFAULT_CONFIG)
    error, session = Spotify.session_create(config)
    raise error if error.is_a?(Spotify::APIError)

    if Spotify.session_remembered_user(session)
      @@logger.info { "Using remembered login for: #{Spotify.session_remembered_user(session)}." }
      Spotify.try(:session_relogin, session)
    else
      @@logger.info "Attempting login under #{username}."
      Spotify.try(:session_login, session, username, password, true, nil)
    end

    @@logger.info 'Log in requested. Waiting forever until logged in.'
    until (Spotify.session_connectionstate(session) == :logged_in)
      Spotify.session_process_events(session)
    end

    at_exit do
      @@logger.info { 'Logging out.' }
      Spotify.session_logout(session)
      Spotify.session_process_events(session) until (Spotify.session_connectionstate(session) != :logged_in )
    end
    session
  end

  def logger
    @@logger
  end
end
